@@ -4,11 +4,12 @@
  * Author:
  * 	Jody Goldberg <jgoldberg@home.com>
  *
- * (C) 1999, 2000 Jody Goldberg
+ * (C) 1999-2001 Jody Goldberg
  */
 #include <config.h>
-#include "gnumeric-type-util.h"
 #include "command-context-priv.h"
+
+#include <gal/util/e-util.h>
 #include <gnome.h> /* Ick.  This is required to get _("") */
 
 #define CC_CLASS(o) COMMAND_CONTEXT_CLASS (GTK_OBJECT (o)->klass)
@@ -94,6 +95,15 @@ gnumeric_error_splits_array (CommandContext *context,
 	CC_CLASS (context)->error.splits_array (context, cmd, array);
 }
 
+void
+gnumeric_error_error_info (CommandContext *context, ErrorInfo *error)
+{
+	g_return_if_fail (IS_COMMAND_CONTEXT (context));
+
+	CC_CLASS (context)->error.error_info (context, error);
+}
+
+
 void
 gnumeric_progress_set (CommandContext *context, gfloat f)
 {
@@ -140,4 +150,5 @@ command_context_pop_err_template (CommandContext *context)
 	}
 }
 
-GNUMERIC_MAKE_TYPE(command_context, "CommandContext", CommandContext, NULL, NULL, gtk_object_get_type ())
+E_MAKE_TYPE (command_context, "CommandContext", CommandContext,
+	     NULL, NULL, GTK_TYPE_OBJECT)
