@@ -7,8 +7,17 @@
  */
 #include <config.h>
 #include <string.h>
+#include <stdlib.h>
+#include <unistd.h>
+#include <fcntl.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <errno.h>
 #include <libgnome/libgnome.h>
 #include <gal/util/e-util.h>
+#ifdef ENABLE_BONOBO
+#include <bonobo/bonobo-exception.h>
+#endif
 #include "file.h"
 #include "io-context.h"
 #include "command-context.h"
@@ -204,6 +213,7 @@ gnum_file_saver_init (GnumFileSaver *fs)
 {
 	fs->id = NULL;
 	fs->extension = NULL;
+	fs->mime_type = NULL;
 	fs->description = NULL;
 	fs->format_level = FILE_FL_NEW;
 	fs->save_scope = FILE_SAVE_WORKBOOK;
@@ -237,12 +247,97 @@ gnum_file_saver_save_real (GnumFileSaver const *fs, IOContext *io_context,
 	fs->save_func (fs, io_context, wbv, file_name);
 }
 
+#ifdef ENABLE_BONOBO
+#define FILE_COPY_CHUNK_SIZE  0x10000
+
+static void
+gnum_file_saver_save_to_stream_real (GnumFileSaver const *fs,
+                                     IOContext *io_context, 
+                                     WorkbookView *wbv, 
+                                     BonoboStream *stream, 
+                                     CORBA_Environment *ev)
+{
+	gchar *tmp_name;
+	gint old_umask;
+	gint fd;
+
+	tmp_name = g_concat_dir_and_file (g_get_tmp_dir (), "gnumeric-file-XXXXXX");
+	old_umask = umask (0077);
+	fd = mkstemp (tmp_name);
+	if (fd == -1) {
+		gnumeric_io_error_info_set (io_context, error_info_new_str_with_details (
+		                            _("Cannot create temporary file."),
+		                            error_info_new_from_errno ()));
+	} else {
+		struct stat sbuf;
+
+		io_progress_range_push (io_context, 0.0, 0.5);
+		gnum_file_saver_save (fs, io_context, wbv, tmp_name);
+		io_progress_range_pop (io_context);
+		(void) unlink (tmp_name);
+
+		if (gnumeric_io_error_occurred (io_context)) {
+			gnumeric_io_error_push (io_context, error_info_new_str (
+			                        _("Error saving to temporary file.")));
+		} else if (fstat (fd, &sbuf) == -1) {
+			gnumeric_io_error_info_set (io_context, error_info_new_str_with_details (
+			                            _("Cannot get temporary file size."),
+			                            error_info_new_from_errno ()));
+		} else {
+			Bonobo_Stream_iobuf *iobuf;
+			gint offset;
+
+			io_progress_message (io_context, _("Saving file to stream."));
+			io_progress_range_push (io_context, 0.5, 1.0);
+			iobuf = Bonobo_Stream_iobuf__alloc ();
+			value_io_progress_set (io_context, sbuf.st_size, FILE_COPY_CHUNK_SIZE);
+			offset = 0;
+			while (1) {
+				gchar buf[FILE_COPY_CHUNK_SIZE];
+				gint read_bytes;
+
+				value_io_progress_update (io_context, offset);
+				read_bytes = read (fd, buf, FILE_COPY_CHUNK_SIZE);
+				if (read_bytes == -1 && errno != EINTR) {
+					gnumeric_io_error_info_set (io_context, error_info_new_str_with_details (
+					                            _("Error reading temporary file."),
+					                            error_info_new_from_errno ()));
+					break;
+				} else if (read_bytes == -1) {
+					continue;
+				} else if (read_bytes == 0) {
+					break;
+				}
+				iobuf->_buffer = buf;
+				iobuf->_length = read_bytes;
+				Bonobo_Stream_write (BONOBO_OBJREF (stream), iobuf, ev);
+				if (BONOBO_EX (ev)) {
+					gnumeric_io_error_string (
+					io_context, _("Exception occured while saving to stream."));
+					break;
+				}
+				offset += read_bytes;
+			}
+			io_progress_unset (io_context);
+			CORBA_free (iobuf);
+			io_progress_range_pop (io_context);
+		}
+		(void) close (fd);
+	}
+	g_free (tmp_name);
+	(void) umask (old_umask);
+}
+#endif
+
 static void
 gnum_file_saver_class_init (GnumFileSaverClass *klass)
 {
 	GTK_OBJECT_CLASS (klass)->destroy = gnum_file_saver_destroy;
 
 	klass->save = gnum_file_saver_save_real;
+#ifdef ENABLE_BONOBO
+	klass->save_to_stream = gnum_file_saver_save_to_stream_real;
+#endif
 }
 
 E_MAKE_TYPE (gnum_file_saver, "GnumFileSaver", GnumFileSaver, \
@@ -269,9 +364,15 @@ gnum_file_saver_setup (GnumFileSaver *fs, const gchar *id,
                        FileFormatLevel level,
                        GnumFileSaverSaveFunc save_func)
 {
+	gchar *tmp;
+
 	g_return_if_fail (IS_GNUM_FILE_SAVER (fs));
 
 	fs->id = g_strdup (id);
+	tmp = g_strdup_printf ("SomeFile.%s", extension);
+	fs->mime_type = gnome_mime_type_or_default (tmp,
+					"application/application/x-gnumeric");
+	g_free (tmp);
 	fs->extension = g_strdup (extension);
 	fs->description = g_strdup (description);
 	fs->format_level = level;
@@ -332,6 +433,14 @@ gnum_file_saver_get_id (GnumFileSaver const *fs)
 	return fs->id;
 }
 
+const gchar *
+gnum_file_saver_get_mime_type (GnumFileSaver const *fs)
+{
+	g_return_val_if_fail (IS_GNUM_FILE_SAVER (fs), FALSE);
+
+	return fs->mime_type;
+}
+
 const gchar *
 gnum_file_saver_get_extension (GnumFileSaver const *fs)
 {
@@ -379,6 +488,31 @@ gnum_file_saver_save (GnumFileSaver const *fs, IOContext *io_context,
 	GNUM_FILE_SAVER_METHOD (fs, save) (fs, io_context, wbv, file_name);
 }
 
+#ifdef ENABLE_BONOBO
+/**
+ * gnum_file_saver_save_to_stream:
+ * @fs		: GnumFileSaver object
+ * @io_context	: Context for i/o operation
+ * @wbv		: Workbook View
+ * @stream	: Bonobo Stream
+ * @ev		: CORBA Environment
+ *
+ * Saves @wbv and workbook it's attached to into the stream. Results are
+ * reported through the environment variable, the i/o context is used only
+ * for updating the progress bar.
+ */
+void
+gnum_file_saver_save_to_stream (GnumFileSaver const *fs, IOContext *io_context,
+                                WorkbookView *wbv, BonoboStream *stream,
+                                CORBA_Environment *ev)
+{
+	bonobo_return_if_fail (IS_GNUM_FILE_SAVER (fs), ev);
+	
+	GNUM_FILE_SAVER_METHOD (fs, save_to_stream) (fs, io_context, wbv,
+	                                             stream, ev);
+}
+#endif
+
 /**
  * gnum_file_saver_fix_file_name:
  * @fs          : GnumFileSaver object
@@ -418,10 +552,15 @@ typedef struct {
 	GnumFileSaver *saver;
 } DefaultFileSaver;
 
+typedef struct {
+	gint priority;
+	GnumFileOpener *opener;
+} DefaultFileImporter;
+
 static GHashTable *file_opener_id_hash = NULL,
                   *file_saver_id_hash = NULL;
 static GList *file_opener_list = NULL, *file_opener_priority_list = NULL;
-static GList *file_importer_list = NULL;
+static GList *file_importer_list = NULL, *default_file_importer_list = NULL;
 static GList *file_saver_list = NULL, *default_file_saver_list = NULL;
 
 static gint
@@ -475,6 +614,14 @@ register_file_opener (GnumFileOpener *fo, gint priority)
 	}
 }
 
+static gint
+default_file_importer_cmp_priority (gconstpointer a, gconstpointer b)
+{
+	const DefaultFileImporter *dfi_a = a, *dfi_b = b;
+
+	return dfi_b->priority - dfi_a->priority;
+}
+
 /**
  * register_file_opener_as_importer:
  * @fo          : GnumFileOpener object
@@ -509,6 +656,42 @@ register_file_opener_as_importer (GnumFileOpener *fo)
 	}
 }
 
+/**
+ * register_file_opener_as_importer_as_default:
+ * @fo          : GnumFileOpener object
+ * @priority    : Opener's priority (as an importer)
+ *
+ * Adds @fo opener to the list of available file importers.
+ * The opener is * also marked as default importer with given priority.
+ * When Gnumeric needs default file importer, it chooses the one with the
+ * highest priority. Recommended range for @priority is [0, 100].
+ * The opener will not be tried when reading files using Gnumeric i/o
+ * routines (unless you call register_file_opener on it), but it will be
+ * available for the user when importing the file and selecting file opener
+ * manually (in that case the default importer will be selected by default).
+ * Reference count for the opener is incremented inside the function, but
+ * you don't have to (and shouldn't) call gtk_object_unref on it if it's
+ * floating object (for example, when you pass object newly created with
+ * gnum_file_opener_new and not referenced anywhere).
+ */
+void
+register_file_opener_as_importer_as_default (GnumFileOpener *fo, gint priority)
+{
+	DefaultFileImporter	*dfi;
+
+	g_return_if_fail (IS_GNUM_FILE_OPENER (fo));
+	g_return_if_fail (priority >=0 && priority <= 100);
+
+	register_file_opener_as_importer (fo);
+
+	dfi = g_new (DefaultFileImporter, 1);
+	dfi->priority = priority;
+	dfi->opener = fo;
+	default_file_importer_list = g_list_insert_sorted (
+	                             default_file_importer_list, dfi,
+	                             default_file_importer_cmp_priority);
+}
+
 /**
  * unregister_file_opener:
  * @fo          : GnumFileOpener object previously registered using
@@ -578,9 +761,37 @@ unregister_file_opener_as_importer (GnumFileOpener *fo)
 		}
 	}
 
+	for (l = default_file_importer_list; l != NULL; l = l->next) {
+		if (((DefaultFileImporter *) l->data)->opener == fo) {
+			default_file_importer_list = g_list_remove_link (default_file_importer_list, l);
+			g_list_free_1 (l);
+			g_free (l->data);
+			break;
+		}
+	}
+
 	gtk_object_unref (GTK_OBJECT (fo));
 }
 
+/**
+ * get_default_file_importer:
+ *
+ * Returns file opener registered as default importer with the highest
+ * priority. Reference count for the saver is NOT incremented.
+ *
+ * Return value: GnumFileOpener object or NULL if default importer is not
+ *               available.
+ */
+GnumFileOpener *
+get_default_file_importer (void)
+{
+	if (default_file_importer_list == NULL) {
+		return NULL;
+	}
+
+	return ((DefaultFileImporter *) default_file_importer_list->data)->opener;
+}
+
 static gint
 default_file_saver_cmp_priority (gconstpointer a, gconstpointer b)
 {
@@ -714,6 +925,28 @@ get_default_file_saver (void)
 	return ((DefaultFileSaver *) default_file_saver_list->data)->saver;
 }
 
+/**
+ * get_file_saver_for_mime_type:
+ * @mime_type: A mime type
+ *
+ * Returns a file saver that claims to save files with given mime type.
+ *
+ * Return value: GnumFileSaver object or NULL if no suitable file saver could
+ *               be found.
+ */
+GnumFileSaver *
+get_file_saver_for_mime_type (const gchar *mime_type)
+{
+	GList *l;
+
+	for (l = file_saver_list; l != NULL; l = l->next) {
+		if (!strcmp (gnum_file_saver_get_mime_type (l->data), mime_type)) {
+			return (l->data);
+		}
+	}
+	return (NULL);
+}
+
 /**
  * get_file_opener_by_id:
  * @id          : File opener's ID
