@@ -7,9 +7,13 @@
  *    Zbigniew Chyla (cyba@gnome.pl)
  */
 #include <config.h>
+#include "gutils.h"
+#include "sheet.h"
+#include "ranges.h"
+
+#include <gnome.h> /* for config */
 #include <stdlib.h>
 #include <stdio.h>
-#include <glib.h>
 #include <string.h>
 #include <ctype.h>
 #include <sys/types.h>
@@ -17,13 +21,7 @@
 #include <sys/wait.h>
 #include <unistd.h>
 #include <fcntl.h>
-#include <gnome.h>
 #include <gal/util/e-util.h>
-#include "numbers.h"
-#include "gutils.h"
-#include "gnumeric.h"
-#include "sheet.h"
-#include "ranges.h"
 
 /* ------------------------------------------------------------------------- */
 
@@ -199,6 +197,21 @@ g_create_list (gpointer item1, ...)
 	return g_list_reverse (list);
 }
 
+gint
+g_list_index_custom (GList *list, gpointer data, GCompareFunc cmp_func)
+{
+	GList *l;
+	gint i;
+
+	for (l = list, i = 0; l != NULL; l = l->next, i++) {
+		if (cmp_func (l->data, data) == 0) {
+			return i;
+		}
+	}
+
+	return -1;
+}
+
 /**
  * g_list_free_custom:
  * @list: list of some items
