@@ -18,10 +18,9 @@
 
 #include "item-edit.h"
 #include "item-cursor.h"
-#include "item-grid.h"
 #define GNUMERIC_ITEM "EDIT"
 #include "item-debug.h"
-#include "gnumeric-sheet.h"
+#include "gnumeric-canvas.h"
 #include "sheet-control-gui-priv.h"
 #include "sheet.h"
 #include "sheet-style.h"
@@ -131,7 +130,7 @@ entry_create_feedback_range (ItemEdit *item_edit, Range *r)
 			"Color",  "red",
 			NULL);
 
-	item_cursor_set_bounds (ITEM_CURSOR (item_edit->feedback_cursor), r);
+	item_cursor_bound_set (ITEM_CURSOR (item_edit->feedback_cursor), r);
 }
 
 static void
@@ -301,7 +300,7 @@ recalc_spans (GnomeCanvasItem *item)
 	Range const *merged;
 
 	/* Adjust the spans */
-	GnumericSheet *gsheet = GNUMERIC_SHEET (item->canvas);
+	GnumericCanvas *gcanvas = GNUMERIC_CANVAS (item->canvas);
 	int cur_line = 1;
 	int cur_col = item_edit->pos.col, max_col = cur_col;
 	ColRowInfo const * cri = sheet_col_get_info (sheet, cur_col);
@@ -318,7 +317,8 @@ recalc_spans (GnomeCanvasItem *item)
 		while (left_in_col < pos_size) {
 			do {
 				++cur_col;
-				if (cur_col > gsheet->col.last_full || cur_col >= SHEET_MAX_COLS) {
+				if (cur_col > gcanvas->last_full.col || cur_col >= SHEET_MAX_COLS) {
+					int height = GTK_WIDGET (gcanvas)->allocation.height;
 					int offset = text - start - 1;
 					if (offset < 0)
 						offset = 0;
@@ -328,7 +328,7 @@ recalc_spans (GnomeCanvasItem *item)
 					text_offsets = g_slist_prepend (text_offsets,
 									GINT_TO_POINTER(offset));
 					if (item->y1 + cur_line * item_edit->font_height >
-					    gsheet->row_offset.last_visible)
+					    (gcanvas->first_offset.row + height))
 						ignore_rows++;
 				} else if (max_col < cur_col)
 					max_col = cur_col;
@@ -505,7 +505,7 @@ item_edit_set_arg (GtkObject *o, GtkArg *arg, guint arg_id)
 {
 	GnomeCanvasItem *item      = GNOME_CANVAS_ITEM (o);
 	ItemEdit        *item_edit = ITEM_EDIT (o);
-	GnumericSheet   *gsheet    = GNUMERIC_SHEET (item->canvas);
+	GnumericCanvas  *gcanvas    = GNUMERIC_CANVAS (item->canvas);
 	Sheet		*sheet;
 	GtkEntry        *entry;
 
@@ -546,12 +546,12 @@ item_edit_set_arg (GtkObject *o, GtkArg *arg, guint arg_id)
 		style_font_unref (sf);
 
 		/* move inwards 1 pixel for the grid line */
-		item->x1 = 1 + gsheet->col_offset.first +
+		item->x1 = 1 + gcanvas->first_offset.col +
 			scg_colrow_distance_get (item_edit->scg, TRUE,
-					  gsheet->col.first, item_edit->pos.col);
-		item->y1 = 1 + gsheet->row_offset.first +
+					  gcanvas->first.col, item_edit->pos.col);
+		item->y1 = 1 + gcanvas->first_offset.row +
 			scg_colrow_distance_get (item_edit->scg, FALSE,
-					  gsheet->row.first, item_edit->pos.row);
+					  gcanvas->first.row, item_edit->pos.row);
 
 		item->x2 = item->x1 + 1;
 		item->y2 = item->y2 + 1;
