@@ -24,7 +24,7 @@
 #include "cell.h"
 #include "sheet-merge.h"
 #include "sheet-private.h"
-#include "sheet-control-gui.h"
+#include "sheet-control.h"
 #include "gnumeric-util.h"
 
 /*
@@ -181,7 +181,7 @@ sheet_selection_redraw (Sheet const *sheet)
 		Range const *r = sel->data;
 
 		SHEET_FOREACH_CONTROL (sheet, control,
-			sc_redraw_cell_region (control,
+			sc_redraw_region (control,
 				r->start.col, r->start.row,
 				r->end.col, r->end.row);
 			sc_redraw_headers (control, TRUE, TRUE, r););
@@ -1038,10 +1038,11 @@ walk_boundaries (Sheet const *sheet, Range const * const bound,
 	ColRowInfo const *cri;
 	int const step = forward ? 1 : -1;
 	CellPos pos = sheet->edit_pos_real;
-	Range const *merge = sheet_merge_is_corner (sheet, &sheet->edit_pos);
+	Range const *merge;
 
 	*res = pos;
 loop :
+	merge = sheet_merge_contains_pos (sheet, &pos);
 	if (horizontal) {
 		if (merge != NULL)
 			pos.col = (forward) ? merge->end.col : merge->start.col;
@@ -1114,7 +1115,7 @@ sheet_selection_walk_step (Sheet *sheet,
 	Range const *ss;
 	gboolean is_singleton = FALSE;
 
-	g_return_if_fail (sheet != NULL);
+	g_return_if_fail (IS_SHEET (sheet));
 	g_return_if_fail (sheet->selections != NULL);
 
 	ss = sheet->selections->data;
