@@ -65,6 +65,7 @@ sheet_merge_add (WorkbookControl *wbc,
 	Cell   *cell;
 	MStyle *style;
 	CellComment *comment;
+	int dummy;
 
 	g_return_val_if_fail (IS_SHEET (sheet), TRUE);
 	g_return_val_if_fail (range_is_sane (r), TRUE);
@@ -84,9 +85,7 @@ sheet_merge_add (WorkbookControl *wbc,
 	if (clear) {
 		int i;
 
-		sheet_redraw_cell_region (sheet,
-					  r->start.col, r->start.row,
-					  r->end.col, r->end.row);
+		sheet_redraw_range (sheet, r);
 
 		/* Clear the non-corner content */
 		if (r->start.col != r->end.col)
@@ -94,13 +93,13 @@ sheet_merge_add (WorkbookControl *wbc,
 					    r->start.col+1, r->start.row,
 					    r->end.col, r->end.row,
 					    CLEAR_VALUES | CLEAR_COMMENTS |
-					    CLEAR_NOCHECKARRAY);
+					    CLEAR_NOCHECKARRAY | CLEAR_NORESPAN);
 		if (r->start.row != r->end.row)
 			sheet_clear_region (wbc, sheet,
 					    r->start.col, r->start.row+1,
 	    /* yes I mean start.col */	    r->start.col, r->end.row,
 					    CLEAR_VALUES | CLEAR_COMMENTS |
-					    CLEAR_NOCHECKARRAY);
+					    CLEAR_NOCHECKARRAY | CLEAR_NORESPAN);
 
 		/* Apply the corner style to the entire region */
 		style = mstyle_copy (sheet_style_get (sheet, r->start.col,
@@ -108,6 +107,7 @@ sheet_merge_add (WorkbookControl *wbc,
 		for (i = MSTYLE_BORDER_TOP; i <= MSTYLE_BORDER_DIAGONAL; i++)
 			mstyle_unset_element (style, i);
 		sheet_style_apply_range (sheet, r, style);
+		sheet_region_queue_recalc (sheet, r);
 	}
 
 	r_copy = range_dup (r);
@@ -122,6 +122,10 @@ sheet_merge_add (WorkbookControl *wbc,
 		cell->base.flags |= CELL_IS_MERGED;
 		cell_unregister_span (cell);
 	}
+	sheet_regen_adjacent_spans (sheet,
+				    r->start.col, r->start.row,
+				    r->start.col, r->end.row,
+				    &dummy, &dummy);
 
 	/* Ensure that edit pos is not in the center of a region. */
 	if (range_contains (r, sheet->edit_pos.col, sheet->edit_pos.row))
