@@ -24,9 +24,10 @@ struct _Workbook {
 	/* Attribute list */
 	GList *attributes;
 
-	char       *filename;
+	gchar          *filename;
 	FileFormatLevel file_format_level;
-	FileSaver      *file_saver;
+	GnumFileSaver  *file_saver;
+	gint            file_saver_sig_id;
 
 	/* Undo support */
 	GSList	   *undo_commands;
@@ -36,19 +37,22 @@ struct _Workbook {
 	GList      *names;
 
 	/* All objects with expressions */
-	GList      *dependents;
+	GSList     *dependents;
 
 	/* The dependents to be evaluated */
-	GList     *eval_queue;
-	int        max_iterations;
-
-	guint8     generation;
+	GSList     *eval_queue;
 
 	/* Attached summary information */
 	SummaryInfo *summary_info;
 
 	void       *corba_server;
 
+	struct {
+		gboolean enabled;
+		int      max_number;
+		double   tolerance;
+	} iteration;
+
 	WorkbookPrivate *priv;
 };
 
@@ -69,11 +73,11 @@ void	    workbook_unref		 (Workbook *wb);
 GList      *workbook_sheets              (Workbook const *wb);
 int         workbook_sheet_count         (Workbook const *wb);
 int	    workbook_sheet_index_get	 (Workbook const *wb, Sheet const * sheet);
-Sheet      *workbook_sheet_by_index	 (Workbook *wb, int i);
-Sheet      *workbook_sheet_by_name       (Workbook *wb, const char *sheet_name);
-void        workbook_sheet_attach        (Workbook *, Sheet *new_sheet,
+Sheet      *workbook_sheet_by_index	 (Workbook const *wb, int i);
+Sheet      *workbook_sheet_by_name       (Workbook const *wb, char const *sheet_name);
+void        workbook_sheet_attach        (Workbook *wb, Sheet *new_sheet,
 					  Sheet const *insert_after);
-gboolean    workbook_sheet_detach        (Workbook *, Sheet *);
+gboolean    workbook_sheet_detach        (Workbook *wb, Sheet *sheet);
 Sheet	   *workbook_sheet_add		 (Workbook *wb,
 					  Sheet const *insert_after,
 					  gboolean make_dirty);
@@ -89,9 +93,11 @@ gboolean    workbook_sheet_rename        (WorkbookControl *,
 					  const char *new_name);
 
 /* IO Routines */
-gboolean    workbook_set_filename        (Workbook *, const char *);
-gboolean    workbook_set_saveinfo        (Workbook *, const gchar *,
-                                          FileFormatLevel, FileSaver *);
+gboolean       workbook_set_filename   (Workbook *wb, const gchar *);
+const gchar   *workbook_get_filename   (Workbook *wb);
+gboolean       workbook_set_saveinfo   (Workbook *wb, const gchar *,
+                                        FileFormatLevel, GnumFileSaver *);
+GnumFileSaver *workbook_get_file_saver (Workbook *wb);
 
 void        workbook_print               (Workbook *, gboolean);
 
@@ -113,12 +119,14 @@ Value	   *workbook_foreach_cell_in_range (EvalPos const *pos,
 					    void	  *closure);
 GPtrArray  *workbook_cells               (Workbook *wb, gboolean comments);
 
+/* Calculation */
+void     workbook_recalc                 (Workbook *wb);	/* in eval.c */
+void     workbook_recalc_all             (Workbook *wb);	/* in eval.c */
+gboolean workbook_enable_recursive_dirty (Workbook *wb, gboolean enable);
+void     workbook_iteration_enabled	 (Workbook *wb, gboolean enable);
+void     workbook_iteration_max_number	 (Workbook *wb, int max_number);
+void     workbook_iteration_tolerance	 (Workbook *wb, double tolerance);
 
-/*
- * Does any pending recalculations
- */
-void        workbook_recalc              (Workbook *wb);
-void        workbook_recalc_all          (Workbook *wb);
 void        workbook_calc_spans          (Workbook *wb, SpanCalcFlags const flags);
 
 /*
