@@ -3,12 +3,13 @@
  *
  * Daniel Veillard <Daniel.Veillard@w3.org>
  *
- * $Id: xml-io.h,v 1.33 2001/07/10 15:45:35 lutz Exp $
+ * $Id: xml-io.h,v 1.34 2001/08/10 23:38:12 lutz Exp $
  */
 
 #ifndef GNUMERIC_XML_IO_H
 #define GNUMERIC_XML_IO_H
 
+#include <gdk/gdktypes.h>
 #ifdef ENABLE_BONOBO
 #include <bonobo/bonobo-stream.h>
 #endif
@@ -108,6 +109,14 @@ void         xml_set_value_string  (xmlNodePtr node, const char *name, const Str
 gboolean     xml_get_value_int     (xmlNodePtr node, const char *name, int *val);
 void         xml_set_value_int     (xmlNodePtr node, const char *name, int val);
 
+GdkColor *xml_get_value_color   (xmlNodePtr node, const char *name);
+void      xml_set_value_color   (xmlNodePtr node, const char *name,
+			         const GdkColor *color);
+gboolean  xml_get_value_double  (xmlNodePtr node, const char *name, double *val);
+void      xml_set_value_double  (xmlNodePtr node, const char *name, double val,
+				 int precision);
+
+
 xmlNodePtr   xml_write_style       (XmlParseContext *ctxt, MStyle *style);
 MStyle      *xml_read_style        (XmlParseContext *ctxt, xmlNodePtr tree);
 
